==> kcmutils-5.97.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5KCMUtils/KF5KCMUtilsTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KCMUtilsCore" for configuration ""
set_property(TARGET KF5::KCMUtilsCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KCMUtilsCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::ConfigCore;KF5::Service;KF5::ItemViews"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KCMUtilsCore.so.5.97.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KCMUtilsCore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KCMUtilsCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KCMUtilsCore "${_IMPORT_PREFIX}/lib/libKF5KCMUtilsCore.so.5.97.0" )

# Import target "KF5::KCMUtils" for configuration ""
set_property(TARGET KF5::KCMUtils APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KCMUtils PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::KCMUtilsCore;Qt5::DBus;Qt5::Qml;Qt5::Quick;Qt5::QuickWidgets;KF5::CoreAddons;KF5::GuiAddons;KF5::I18n;KF5::ItemViews;KF5::XmlGui;KF5::QuickAddons;KF5::Declarative"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KCMUtils.so.5.97.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KCMUtils.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::KCMUtils )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::KCMUtils "${_IMPORT_PREFIX}/lib/libKF5KCMUtils.so.5.97.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kcmutils-5.99.0-2-aarch64.pkg.tar.xz: usr/lib/cmake/KF5KCMUtils/KF5KCMUtilsTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::KCMUtilsCore" for configuration ""
set_property(TARGET KF5::KCMUtilsCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KCMUtilsCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::ConfigCore;KF5::Service;KF5::ItemViews"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KCMUtilsCore.so.5.99.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KCMUtilsCore.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::KCMUtilsCore )
list(APPEND _cmake_import_check_files_for_KF5::KCMUtilsCore "${_IMPORT_PREFIX}/lib/libKF5KCMUtilsCore.so.5.99.0" )

# Import target "KF5::KCMUtils" for configuration ""
set_property(TARGET KF5::KCMUtils APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::KCMUtils PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::KCMUtilsCore;Qt5::DBus;Qt5::Qml;Qt5::Quick;Qt5::QuickWidgets;KF5::CoreAddons;KF5::GuiAddons;KF5::I18n;KF5::ItemViews;KF5::XmlGui;KF5::QuickAddons;KF5::Declarative"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KCMUtils.so.5.99.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KCMUtils.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::KCMUtils )
list(APPEND _cmake_import_check_files_for_KF5::KCMUtils "${_IMPORT_PREFIX}/lib/libKF5KCMUtils.so.5.99.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
